@@ -1,24 +1,24 @@
 test_that("Checking column name spelling", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   names(chk)[c(1, 3)] <- c('Site ID', 'latitude')
   expect_error(checkMWRsites(chk))
 })
 
 test_that("Checking required column names are present", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   chk <- chk[, -5]
   expect_error(checkMWRsites(chk))
 })
 
 test_that("Checking missing latitude or longitude", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   chk$`Monitoring Location Longitude`[5] <- NA
   chk$`Monitoring Location Latitude`[c(5, 6, 11)] <- NA
   expect_error(checkMWRsites(chk))
 })
 
 test_that("Checking non-numeric latitude", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   chk$`Monitoring Location Latitude`[5] <- 'a'
   chk$`Monitoring Location Latitude`[6] <- 'b'
   chk$`Monitoring Location Latitude`[11] <- 'a'
@@ -26,7 +26,7 @@ test_that("Checking non-numeric latitude", {
 })
 
 test_that("Checking non-numeric longitude", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   chk$`Monitoring Location Longitude`[4] <- 'a'
   chk$`Monitoring Location Longitude`[6] <- 'b'
   chk$`Monitoring Location Longitude`[11] <- 'a'
@@ -34,7 +34,7 @@ test_that("Checking non-numeric longitude", {
 })
 
 test_that("Checking positive values in longitude", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   chk$`Monitoring Location Longitude`[5] <- 72
   chk$`Monitoring Location Longitude`[6] <- 72
   chk$`Monitoring Location Longitude`[11] <- 73
@@ -42,7 +42,7 @@ test_that("Checking positive values in longitude", {
 })
 
 test_that("Checking missing locatoin id", {
-  chk <- sitdatchk
+  chk <- tst$sitdatchk
   chk$`Monitoring Location ID`[4] <- NA
   chk$`Monitoring Location ID`[7] <- NA
   expect_error(checkMWRsites(chk))
