@@ -1,4 +1,4 @@
 test_that("Checking dqo accuracy output format", {
-  result <- readMWRacc(accpth)
+  result <- readMWRacc(tst$accpth)
   expect_s3_class(result, 'tbl_df')
 })
