@@ -1,4 +1,4 @@
 test_that("Checking dqo frequency and completeness output format", {
-  result <- readMWRfrecom(frecompth)
+  result <- readMWRfrecom(tst$frecompth)
   expect_s3_class(result, 'tbl_df')
 })
