@@ -1,4 +1,4 @@
 test_that("Checking sites output format", {
-  result <- readMWRsites(sitpth)
+  result <- readMWRsites(tst$sitpth)
   expect_s3_class(result, 'tbl_df')
 })
