@@ -3,5 +3,5 @@ test_that("Missing arguments for input check", {
 })
 
 test_that("Missing fset elements for input check", {
-  expect_error(tabMWRcom(fset = list(res = resdat)))
-})
\ No newline at end of file
+  expect_error(tabMWRcom(fset = list(res = tst$resdat)))
+})
