@@ -1,19 +1,19 @@
 test_that("geomean auto", {
-  result <- utilMWRsumfun(accdat, param = 'E.coli')
+  result <- utilMWRsumfun(tst$accdat, param = 'E.coli')
   expect_equal(result, 'geomean')
 })
 
 test_that("mean force", {
-  result <- utilMWRsumfun(accdat, param = 'E.coli', sumfun = 'mean')
+  result <- utilMWRsumfun(tst$accdat, param = 'E.coli', sumfun = 'mean')
   expect_equal(result, 'mean')
 })
 
 test_that("mean auto", {
-  result <- utilMWRsumfun(accdat, param = 'DO')
+  result <- utilMWRsumfun(tst$accdat, param = 'DO')
   expect_equal(result, 'mean')
 })
 
 test_that("geomean force", {
-  result <- utilMWRsumfun(accdat, param = 'DO', sumfun = 'geomean')
+  result <- utilMWRsumfun(tst$accdat, param = 'DO', sumfun = 'geomean')
   expect_equal(result, 'geomean')
-})
\ No newline at end of file
+})
