@@ -1,43 +1,43 @@
 test_that("Checking output format", {
-  result <- utilMWRthresh(resdat, param = 'TP', thresh = 'fresh')
+  result <- utilMWRthresh(tst$resdat, param = 'TP', thresh = 'fresh')
   expect_s3_class(result, 'tbl_df')
 })
 
 test_that("Checking output format, pH exception", {
-  result <- utilMWRthresh(resdat, param = 'pH', thresh = 'fresh')
+  result <- utilMWRthresh(tst$resdat, param = 'pH', thresh = 'fresh')
   expect_s3_class(result, 'tbl_df')
 })
 
 test_that("Checking output format no marine threshold", {
-  expect_null(utilMWRthresh(resdat, param = 'TP', thresh = 'marine'))
+  expect_null(utilMWRthresh(tst$resdat, param = 'TP', thresh = 'marine'))
 })
 
 test_that("Checking output format none", {
-  expect_null(utilMWRthresh(resdat, param = 'TP', thresh = 'none'))
+  expect_null(utilMWRthresh(tst$resdat, param = 'TP', thresh = 'none'))
 })
 
 test_that("Checking output format no parameter", {
-  expect_null(utilMWRthresh(resdat, param = 'asdf', thresh = 'marine'))
+  expect_null(utilMWRthresh(tst$resdat, param = 'asdf', thresh = 'marine'))
 })
 
 test_that("Checking error if unit mismatch",{
   
-  resdatchk <- resdat %>% 
+  tst$resdatchk <- tst$resdat %>% 
     mutate(
       `Result Unit` = case_when(
         `Characteristic Name` == 'TP' ~ 'mmol/l', 
         TRUE ~ `Result Unit`
       )
     )
-  expect_error(utilMWRthresh(resdatchk, param = 'TP', thresh = 'marine'))
+  expect_error(utilMWRthresh(tst$resdatchk, param = 'TP', thresh = 'marine'))
   
 })
 
 test_that("Checking output numeric", {
-  result <- utilMWRthresh(resdat, param = 'TP', thresh = 5, threshlab = 'test')
+  result <- utilMWRthresh(tst$resdat, param = 'TP', thresh = 5, threshlab = 'test')
   expect_s3_class(result, 'data.frame')
 })
 
 test_that("Checking error if output numeric and no threshlab", {
-  expect_error(utilMWRthresh(resdat, param = 'TP', thresh = 5))
-})
\ No newline at end of file
+  expect_error(utilMWRthresh(tst$resdat, param = 'TP', thresh = 5))
+})
