@@ -4,7 +4,7 @@ test_that("title with parameter only", {
 })
 
 test_that("title with parameter and summary function", {
-  result <- utilMWRtitle(param = 'DO', accdat = accdat, sumfun = "auto")
+  result <- utilMWRtitle(param = 'DO', accdat = tst$accdat, sumfun = "auto")
   expect_equal(result, 'DO (mean)')
 })
 
@@ -17,4 +17,4 @@ test_that("title with parameter and all filters", {
   result <- utilMWRtitle(param = 'DO', site = 'test', dtrng = c('2021-05-01', '2021-07-31'), 
                          resultatt = 'test', locgroup = 'test')
   expect_equal(result, 'DO, data filtered by sites, dates (1 May, 2021 to 31 July, 2021), result attributes, location groups')
-})
\ No newline at end of file
+})
